@@ -1506,15 +1506,14 @@ class SQLGenerator(object):
         value = constant.value
         if constant.type == 'etype':
             return value
-        if constant.type == 'Int': # XXX Float?
+        # don't substitute int, causes pb when used as sorting column number
+        if constant.type == 'Int':
             return str(value)
         if constant.type in ('Date', 'Datetime'):
             rel = constant.relation()
             if rel is not None:
                 rel._q_needcast = value
             return self.keyword_map[value]()
-        if constant.type == 'Boolean':
-            return str(self.dbhelper.boolean_value(value))
         if constant.type == 'Substitute':
             try:
                 # we may found constant from simplified var in varmap
